@@ -7,7 +7,7 @@
 #  88              d8'                              88
 
 __title__ = "pycspr"
-__version__ = "0.11.0"
+__version__ = "1.0.1"
 __author__ = "Mark A. Greenslade et al"
 __license__ = "Apache 2.0"
 
@@ -23,6 +23,8 @@ from pycspr.api.sse_types import NodeEventChannel
 from pycspr.api.sse_types import NodeEventInfo
 from pycspr.api.sse_types import NodeEventType
 
+from pycspr.crypto import DEFAULT_HASH_ALGO
+from pycspr.crypto import DEFAULT_KEY_ALGO
 from pycspr.crypto import get_account_hash
 from pycspr.crypto import get_account_key
 from pycspr.crypto import get_account_key_algo
@@ -32,6 +34,7 @@ from pycspr.crypto import KeyAlgorithm
 
 from pycspr.factory import create_deploy
 from pycspr.factory import create_deploy_approval
+from pycspr.factory import create_deploy_arguments
 from pycspr.factory import create_deploy_parameters
 from pycspr.factory import create_deploy_ttl
 from pycspr.factory import create_transfer
@@ -45,6 +48,18 @@ from pycspr.factory import parse_private_key_bytes
 from pycspr.factory import parse_public_key
 from pycspr.factory import parse_public_key_bytes
 
+from pycspr.serialisation import to_bytes
+from pycspr.serialisation import to_json
+from pycspr.serialisation import from_bytes
+from pycspr.serialisation import from_json
+
+from pycspr.types import PublicKey
+from pycspr.types import PrivateKey
+
+from pycspr.utils.io import get_deploy_size_bytes
 from pycspr.utils.io import read_deploy
 from pycspr.utils.io import read_wasm
 from pycspr.utils.io import write_deploy
+
+from pycspr.utils.validation import validate_deploy
+from pycspr.utils.validation import InvalidDeployException
