@@ -5,7 +5,6 @@ from pycspr.types import CL_U64
 from pycspr.types import CL_ByteArray
 from pycspr.types import CL_List
 from pycspr.types import CL_String
-from pycspr.types import CL_Type_String
 from pycspr.types import DeployExecutableItem
 from pycspr.types import DeployHeader
 
@@ -18,25 +17,25 @@ def create_digest_of_deploy(header: DeployHeader) -> bytes:
 
     """
     return crypto.get_hash(
-        serialisation.cl_value_to_bytes(
+        serialisation.to_bytes(
             CL_PublicKey.from_public_key(header.account_public_key)
         ) +
-        serialisation.cl_value_to_bytes(
+        serialisation.to_bytes(
             CL_U64(int(header.timestamp.value * 1000))
         ) +
-        serialisation.cl_value_to_bytes(
+        serialisation.to_bytes(
             CL_U64(header.ttl.as_milliseconds)
         ) +
-        serialisation.cl_value_to_bytes(
-             CL_U64(header.gas_price)
+        serialisation.to_bytes(
+            CL_U64(header.gas_price)
         ) +
-        serialisation.cl_value_to_bytes(
+        serialisation.to_bytes(
             CL_ByteArray(header.body_hash)
         ) +
-        serialisation.cl_value_to_bytes(
-            CL_List(header.dependencies, CL_Type_String())
+        serialisation.to_bytes(
+            CL_List(header.dependencies)
         ) +
-        serialisation.cl_value_to_bytes(
+        serialisation.to_bytes(
             CL_String(header.chain_name)
         )
     )
@@ -54,6 +53,6 @@ def create_digest_of_deploy_body(
 
     """
     return crypto.get_hash(
-        serialisation.deploy_to_bytes(payment) +
-        serialisation.deploy_to_bytes(session)
+        serialisation.to_bytes(payment) +
+        serialisation.to_bytes(session)
         )
