@@ -79,6 +79,8 @@ from pycspr.types.identifiers import DictionaryID_SeedURef
 from pycspr.types.identifiers import DictionaryID_UniqueKey
 from pycspr.types.identifiers import GlobalStateID
 from pycspr.types.identifiers import GlobalStateIDType
+from pycspr.types.identifiers import PurseID
+from pycspr.types.identifiers import PurseIDType
 from pycspr.types.identifiers import StateRootHash
 
 from pycspr.types.keys import PrivateKey
@@ -138,3 +140,19 @@ CL_TYPEKEY_TO_CL_TYPE = {
     CL_TypeKey.UNIT: CL_Type_Unit,
     CL_TypeKey.UREF: CL_Type_URef,
 }
+
+DEPLOY_EXECUTABLE_ITEM_VARIANTS = (
+    ModuleBytes,
+    StoredContractByHash,
+    StoredContractByHashVersioned,
+    StoredContractByName,
+    StoredContractByNameVersioned,
+    Transfer,
+)
+
+DICTIONARY_ID_VARIANTS = (
+    DictionaryID_AccountNamedKey,
+    DictionaryID_ContractNamedKey,
+    DictionaryID_SeedURef,
+    DictionaryID_UniqueKey
+)
