@@ -3,9 +3,29 @@ import pathlib
 import typing
 
 from pycspr import serialisation
+from pycspr import factory
 from pycspr.types import Deploy
 
 
+def get_deploy_size_bytes(deploy: Deploy) -> int:
+    """Returns size of a deploy in bytes.
+
+    :deploy: Deploy to be written in JSON format.
+    :returns: Size of deploy in bytes.
+
+    """
+    size: int = len(deploy.hash)
+    for approval in deploy.approvals:
+        size += len(approval.signature)
+        size += len(approval.signer)
+        size += len(serialisation.to_bytes(deploy.header))
+        size += len(serialisation.to_bytes(
+            factory.create_deploy_body(deploy.payment, deploy.session))
+        )
+
+    return size
+
+
 def read_deploy(fpath: typing.Union[pathlib.Path, str]) -> Deploy:
     """Reads a deploy from file system.
 
@@ -14,7 +34,7 @@ def read_deploy(fpath: typing.Union[pathlib.Path, str]) -> Deploy:
     """
     fpath = pathlib.Path(fpath) if isinstance(fpath, str) else fpath
     with open(str(fpath), "r") as fstream:
-        return serialisation.deploy_from_json(Deploy, json.loads(fstream.read()))
+        return serialisation.from_json(json.loads(fstream.read()), Deploy)
 
 
 def read_wasm(fpath: typing.Union[pathlib.Path, str]) -> bytes:
@@ -49,6 +69,6 @@ def write_deploy(
         raise IOError("Deploy has already been written to file system")
 
     with open(str(fpath), "w") as fstream:
-        fstream.writelines(json.dumps(serialisation.deploy_to_json(deploy), indent=4))
+        fstream.writelines(json.dumps(serialisation.to_json(deploy), indent=4))
 
     return str(fpath)
